@@ -356,35 +356,13 @@ void gnc_main_window_save_all_windows(GKeyFile *keyfile);
  */
 void gnc_main_window_restore_default_state(GncMainWindow *window);
 
-/**
- * gnc_gtk_action_group_set_translation_domain:
- * @param action_group a #GtkActionGroup
- * @param domain the translation domain to use for dgettext() calls
- *
- * Sets the translation domain and uses dgettext() for translating the
- * @a label and @a tooltip of #GtkActionEntry<!-- -->s added by
- * gtk_action_group_add_actions().
- *
- * This is copied from gtk's gtk_action_group_set_translation_domain()
- * into GnuCash in order to fix problems when empty msgids were passed
- * through gettext().
- *
- * See http://bugzilla.gnome.org/show_bug.cgi?id=326200 . If that bug
- * is fixed in the gtk that we can rely open, then
- * gnc_gtk_action_group_set_translation_domain can be replaced by
- * gtk_action_group_set_translation_domain again.
- **/
-void
-gnc_gtk_action_group_set_translation_domain (GtkActionGroup *action_group,
-        const gchar    *domain);
-
 
 /** Tell a window to finish any outstanding activities.  This function
  *  will call gnc_plugin_page_finish_pending for each installed page.
  *  If any page returns a failure indication, then the function stops
  *  walking pages and immediately returns a failure.
  *
- *  @param window Whe window whose pages should be checked.
+ *  @param window When window whose pages should be checked.
  *
  *  @return FALSE if any page could not or would not comply, which
  *  should cancel the pending operation.  TRUE otherwise */
@@ -413,7 +391,7 @@ void gnc_main_window_all_action_set_sensitive (const gchar *action_name, gboolea
 
 /** Find action in main window.
  *
- *  @param window Whe window which should be checked for the action.
+ *  @param window When window which should be checked for the action.
  *
  *  @param name The name of the command to be retrieved.
  *
@@ -446,7 +424,7 @@ GtkWidget *gnc_book_options_dialog_cb (gboolean modal, gchar *title,
 
 /**
  * Processes selected options in the Book Options dialog: checks book_currency
- * and use_split_action_for_num to see if features kvp shuold be set. To be used
+ * and use_split_action_for_num to see if features kvp should be set. To be used
  * where ever a new book situation requires book option selection (e.g., not
  * just in Book Options dialog opened from main window but also in new-file
  * assistant).
