@@ -46,6 +46,16 @@ typedef QofSession * (*QofSessionCB) (void);
 gchar *gnc_normalize_account_separator (const gchar* separator);
 gboolean gnc_reverse_balance(const Account *account);
 
+/* Backward compatibility *******************************************
+ * Return book's UNREVERSED_BUDGET feature check. */
+gboolean gnc_using_unreversed_budgets (QofBook* book);
+
+/* Backward compatibility *******************************************
+ * Compare book's UNREVERSED_BUDGET with unreverse_check. If they
+ * match, return account reversal according to global pref. If they
+ * don't match, return FALSE. */
+gboolean gnc_reverse_budget_balance (const Account *account, gboolean unreversed);
+
 /* Default directory sections ***************************************/
 #define GNC_PREFS_GROUP_OPEN_SAVE    "dialogs.open-save"
 #define GNC_PREFS_GROUP_EXPORT       "dialogs.export-accounts"
@@ -72,9 +82,11 @@ QofBook * gnc_get_current_book (void);
  * need to check as well for a book with no accounts (root with no children). */
 gboolean gnc_is_new_book (void);
 
-void gnc_set_current_book_tax_name (const gchar *tax_name);
+void gnc_set_current_book_tax_name_type (gboolean name_changed,
+                                            const gchar *tax_name,
+                                            gboolean type_changed,
+                                            const gchar *tax_type);
 const gchar * gnc_get_current_book_tax_name (void);
-void gnc_set_current_book_tax_type (const gchar *tax_type);
 const gchar * gnc_get_current_book_tax_type (void);
 /** Calls gnc_book_option_num_field_source_change to initiate registered
   * callbacks when num_field_source book option changes so that
@@ -293,7 +305,7 @@ GNCPrintAmountInfo gnc_split_amount_print_info (Split *split,
 
 GNCPrintAmountInfo gnc_share_print_info_places (int decplaces);
 GNCPrintAmountInfo gnc_default_share_print_info (void);
-GNCPrintAmountInfo gnc_default_price_print_info (void);
+GNCPrintAmountInfo gnc_default_price_print_info (const gnc_commodity *curr);
 
 GNCPrintAmountInfo gnc_integral_print_info (void);
 
@@ -321,6 +333,19 @@ gchar *numeric_to_words(gnc_numeric val);
 gboolean xaccParseAmount (const char * in_str, gboolean monetary,
                           gnc_numeric *result, char **endstr);
 
+/*
+ * xaccParseAmountPosSign is just like xaccParseAmount except the
+ * caller can choose whether the locale's postive sign (or in absense
+ * the '+') character is ignored. Setting skip to TRUE will cause
+ * the function to ignore any positive sign. Setting it to FALSE,
+ * and positive signs will be treated as unrecognized characters.
+ * xaccParseAmount will run as if skip is FALSE for compatibility
+ * reasons (gnc-expression-parser depends on this behaviour).
+ */
+gboolean
+xaccParseAmountPosSign (const char * in_str, gboolean monetary, gnc_numeric *result,
+                        char **endstr, gboolean skip);
+
 /*
  * xaccParseAmountExtended is just like xaccParseAmount except the
  * caller must provide all the locale-specific information.
